@@ -1,4 +1,4 @@
-# Copyright (c) 2017-2018 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2017-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -54,17 +54,30 @@ class WebViewJsSignals:
             GLib.source_remove(self.__js_blocker_timeout_id)
             self.__js_blocker_timeout_id = None
         message = dialog.get_message()
+        if message.startswith("@EOLIE_CSS_URI@"):
+            webview.load_css_uri(message)
+        elif message.startswith("@EOLIE_CSS_TEXT@"):
+            webview.load_css_text(message)
+        # Credentials message
+        elif message.startswith("@EOLIE_SUBMIT@"):
+            webview.add_credentials(message)
+        # Input menu message
+        elif message.startswith("@EOLIE_FORM_MENU_MESSAGE@"):
+            webview.show_form_menu(message)
+        # Focus message
+        elif message.startswith("@EOLIE_FOCUS_MESSAGE@"):
+            self.window.toolbar.title.show_input_warning(self)
         # Reader js message
-        if message.startswith("@EOLIE_READER@"):
+        elif message.startswith("@EOLIE_READER@"):
             self.emit("readability-content",
                       message.replace("@EOLIE_READER@", ""))
         elif message.startswith("@EOLIE_READERABLE@"):
-            self._readable = True
-            self._window.toolbar.title.show_readable_button(True)
+            self._readability = True
+            self.emit("readability-status", True)
         # OpenSearch message
         elif message.startswith("@EOLIE_OPENSEARCH@"):
             uri = message.replace("@EOLIE_OPENSEARCH@", "")
-            App().search.install_engine(uri, self._window)
+            App().search.install_engine(uri, self.window)
         # Populars view message
         elif message.startswith("@EOLIE_HIDE_BOOKMARK_POPULARS@"):
             uri = message.replace("@EOLIE_HIDE_BOOKMARK_POPULARS@", "")
@@ -76,12 +89,12 @@ class WebViewJsSignals:
         # Here we handle JS flood
         elif self.__js_blocker_count > 5:
             self.__js_blocker_count = 0
-            self._window.toolbar.title.show_message(
+            self.window.toolbar.title.show_message(
                 _("Eolie is going to close this page because it is broken"))
-            self._window.container.close_view(self.view)
+            self.window.container.close_webview(self.view)
         # Webpage message
         else:
-            self._window.toolbar.title.show_javascript(dialog)
+            self.window.toolbar.title.show_javascript(dialog)
             self.__js_blocker_count += 1
             self.__js_blocker_timeout_id = GLib.timeout_add(
                 1000,
